@@ -1,4 +1,4 @@
 // Globally available exports
-pub mod types;
 pub mod header;
-pub mod registry;
\ No newline at end of file
+pub mod reg_entry;
+pub mod types;
